
# Slot: links




URI: [nwb_schema_language:links](https://w3id.org/p2p_ld/nwb-schema-language/links)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Link](Link.md)

## Parents


## Children


## Used by

 * [Group](Group.md)
